@@ -34,7 +34,7 @@
 
 ;; FIXME Should handle multibyte regular expressions
 (compat-defun string-search (needle haystack &optional start-pos) ;; <compat-tests:string-search>
-  "Search for the string NEEDLE in the strign HAYSTACK.
+  "Search for the string NEEDLE in the string HAYSTACK.
 
 The return value is the position of the first occurrence of
 NEEDLE in HAYSTACK, or nil if no match was found.
@@ -52,9 +52,8 @@ issues are inherited."
   (when (and start-pos (or (< (length haystack) start-pos)
                            (< start-pos 0)))
     (signal 'args-out-of-range (list start-pos)))
-  (save-match-data
-    (let ((case-fold-search nil))
-      (string-match (regexp-quote needle) haystack start-pos))))
+  (let (case-fold-search)
+    (string-match-p (regexp-quote needle) haystack start-pos)))
 
 (compat-defun length= (sequence length) ;; [[compat-tests:length=]]
   "Returns non-nil if SEQUENCE has a length equal to LENGTH."
@@ -66,7 +65,7 @@ issues are inherited."
          t))
    ((arrayp sequence)
     (= (length sequence) length))
-   ((signal 'wrong-type-argument sequence))))
+   (t (signal 'wrong-type-argument (list 'sequencep sequence)))))
 
 (compat-defun length< (sequence length) ;; [[compat-tests:length<]]
   "Returns non-nil if SEQUENCE is shorter than LENGTH."
@@ -76,7 +75,7 @@ issues are inherited."
     (null (nthcdr (1- length) sequence)))
    ((arrayp sequence)
     (< (length sequence) length))
-   ((signal 'wrong-type-argument sequence))))
+   (t (signal 'wrong-type-argument (list 'sequencep sequence)))))
 
 (compat-defun length> (sequence length) ;; [[compat-tests:length>]]
   "Returns non-nil if SEQUENCE is longer than LENGTH."
@@ -85,7 +84,7 @@ issues are inherited."
     (and (nthcdr length sequence) t))
    ((arrayp sequence)
     (> (length sequence) length))
-   ((signal 'wrong-type-argument sequence))))
+   (t (signal 'wrong-type-argument (list 'sequencep sequence)))))
 
 ;;;; Defined in fileio.c
 
@@ -355,11 +354,10 @@ REPLACEMENT can use the following special elements:
 (compat-defun buffer-local-boundp (symbol buffer) ;; <compat-tests:buffer-local-boundp>
   "Return non-nil if SYMBOL is bound in BUFFER.
 Also see `local-variable-p'."
-  (catch 'fail
-    (condition-case nil
-        (buffer-local-value symbol buffer)
-      (void-variable nil (throw 'fail nil)))
-    t))
+  (condition-case nil
+      (progn (buffer-local-value symbol buffer)
+             t)
+    (void-variable nil)))
 
 (compat-defmacro with-existing-directory (&rest body) ;; <compat-tests:with-existing-directory>
   "Execute BODY with `default-directory' bound to an existing directory.
